.. _infrastructure_overview.rst:

=======================
Infrastructure overview
=======================

Structure graphics of the Plone Intranet Consortium organisational infrastructure (Digital Workplace).

TBAL